@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import abc
 import fnmatch
+import itertools
 import re
 import subprocess
 import tempfile
@@ -61,6 +62,7 @@ class FileDescriptorSetGenerator(abc.ABC):
         """Fix imports from protoc/buf generated code."""
         fdset = FileDescriptorSet.FromString(self.generate_file_descriptor_set_bytes())
 
+        has_pyi = any(suffix.endswith(".pyi") for suffix in module_suffixes)
         for fd in fdset.file:
             if _should_ignore(fd.name, exclude_imports_glob):
                 continue
@@ -94,12 +96,21 @@ class FileDescriptorSetGenerator(abc.ABC):
                     overwrite_callback(python_file, new_code)
 
         if create_package:
-            python_out.joinpath("__init__.py").touch(exist_ok=True)
-
             # recursively create packages
-            for dir_entry in python_out.rglob("*"):
+            for dir_entry in itertools.chain([python_out], python_out.rglob("*")):
                 if dir_entry.is_dir():
                     dir_entry.joinpath("__init__.py").touch(exist_ok=True)
+                    if has_pyi:
+                        _create_pyi_init(dir_entry)
+
+
+def _create_pyi_init(root: Path) -> None:
+    with root.joinpath("__init__.pyi").open(mode="a") as f:
+        f.writelines(
+            f"from . import {path.stem}\n"
+            for path in root.glob("*")
+            if path.stem != "__init__" and (path.suffix == ".pyi" or path.is_dir())
+        )
 
 
 class Protoc(FileDescriptorSetGenerator):
